summaryrefslogtreecommitdiff
path: root/debian/patches/source-spelling.patch
blob: 2b1632c4f2682f9bbf09d47795381e61900d43e3 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
Description:
 Correction of some spelling/grammatical errors in source code.
Author: Mark Buda <hermit@acm.org>

--- a/backend/abaton.c
+++ b/backend/abaton.c
@@ -1455,7 +1455,7 @@
       if (s->AbortedByUser)
 	{
 	  DBG (FLOW_CONTROL, "sane_cancel: Scan has not been initiated yet."
-	       "we probably recieved a signal while writing data.\n");
+	       "we probably received a signal while writing data.\n");
 	  s->AbortedByUser = SANE_FALSE;
 	}
       else
--- a/backend/apple.c
+++ b/backend/apple.c
@@ -1596,7 +1596,7 @@
   s->opt[OPT_WAIT].title = "Wait";
   s->opt[OPT_WAIT].desc = "You may issue the scan command but the actual "
   "scan will not start unless you press the button in the front of the "
-  "scanner. It is usefull feature when you want to make a network scan (?) "
+  "scanner. It is a useful feature when you want to make a network scan (?) "
   "In the mean time you may halt your computer waiting for the SCSI bus "
   "to be free. If this happens just press the scanner button.";
   s->opt[OPT_WAIT].type = SANE_TYPE_BOOL;
--- a/backend/artec.c
+++ b/backend/artec.c
@@ -607,7 +607,7 @@
 	  return SANE_STATUS_IO_ERROR;
 	}
     default:
-      DBG (2, "sense: Unkown Error Code Qualifier (%02x)\n", sense[0]);
+      DBG (2, "sense: Unknown Error Code Qualifier (%02x)\n", sense[0]);
       return SANE_STATUS_IO_ERROR;
     }
 
--- a/backend/coolscan.c
+++ b/backend/coolscan.c
@@ -179,7 +179,7 @@
 
     case 0x2:
       if ((0x4 == asc) && (0x1 == ascq)) {
-	DBG (10, "\t%d/%d/%d: Logical unit is in process of becomming ready\n", 
+	DBG (10, "\t%d/%d/%d: Logical unit is in process of becoming ready\n",
 	     sense, asc, ascq);
 	ret = SANE_STATUS_DEVICE_BUSY;
       }
--- a/backend/hp3900_debug.c
+++ b/backend/hp3900_debug.c
@@ -597,7 +597,7 @@
 	}
       else
 	DBG (DBG_ERR,
-	     "- dbg_tiff_save: Enviroment HOME variable does not exist\n");
+	     "- dbg_tiff_save: Environment HOME variable does not exist\n");
     }
 #else
   /* silent gcc */
--- a/backend/hp3900_sane.c
+++ b/backend/hp3900_sane.c
@@ -1405,7 +1405,7 @@
 	      pDesc->title = SANE_I18N ("Scanner model");
 	      pDesc->desc =
 		SANE_I18N
-		("Allows to test device behaviour with other supported models");
+		("Allows one to test device behaviour with other supported models");
 	      pDesc->type = SANE_TYPE_STRING;
 	      pDesc->size = max_string_size (scanner->list_models);
 	      pDesc->constraint_type = SANE_CONSTRAINT_STRING_LIST;
--- a/backend/mustek_pp_ccd300.c
+++ b/backend/mustek_pp_ccd300.c
@@ -1660,7 +1660,7 @@
 
   if (caps & ~(CAP_NOTHING | CAP_INVERT | CAP_LAMP_OFF))
     {
-      DBG (1, "ccd300_open: called with unknonw capabilities (%#02x)\n",
+      DBG (1, "ccd300_open: called with unknown capabilities (%#02x)\n",
 	   caps);
       return SANE_STATUS_INVAL;
     }
@@ -1816,7 +1816,7 @@
     }
   else
     {
-      DBG (1, "ccd300_config: unkown option ``%s''", optname);
+      DBG (1, "ccd300_config: unknown option ``%s''", optname);
       return SANE_STATUS_INVAL;
     }
 
--- a/backend/pnm.c
+++ b/backend/pnm.c
@@ -267,7 +267,7 @@
    SANE_I18N ("Hand-Scanner Simulation"),
    SANE_I18N ("Simulate a hand-scanner.  Hand-scanners often do not know the "
 	      "image height a priori.  Instead, they return a height of -1.  "
-	      "Setting this option allows to test whether a frontend can "
+	      "Setting this option allows one to test whether a frontend can "
 	      "handle this correctly."),
    SANE_TYPE_BOOL,
    SANE_UNIT_NONE,
--- a/backend/umax.c
+++ b/backend/umax.c
@@ -1035,7 +1035,7 @@
 
       if (asc == 0x00)
       {
-        DBG(DBG_sense, "-> button protocoll\n");
+        DBG(DBG_sense, "-> button protocol\n");
         if (ascq & 1)
         {
           dev->button0_pressed = 1;
--- a/backend/umax_pp_low.c
+++ b/backend/umax_pp_low.c
@@ -10900,7 +10900,7 @@
 
       /* scan time are high enough to forget about usec */
       elapsed = tf.tv_sec - td.tv_sec;
-      DBG (8, "%ld bytes transfered in %f seconds ( %.2f Kb/s)\n", somme,
+      DBG (8, "%ld bytes transferred in %f seconds ( %.2f Kb/s)\n", somme,
 	   elapsed, (somme / elapsed) / 1024.0);
 #endif
 
--- a/frontend/scanimage.c
+++ b/frontend/scanimage.c
@@ -250,7 +250,7 @@
       md5mode = 1;
       len = (strstr (resource, "$MD5$") - resource);
       if (query_user == 1)
-	fprintf (stderr, "Authentification required for resource %*.*s. "
+	fprintf (stderr, "Authentication required for resource %*.*s. "
 		 "Enter username: ", len, len, resource);
     }
   else
@@ -270,7 +270,7 @@
 
       if (query_user == 1)
 	fprintf (stderr,
-		 "Authentification required for resource %s. Enter username: ",
+		 "Authentication required for resource %s. Enter username: ",
 		 resource);
     }
 
--- a/po/bg.po
+++ b/po/bg.po
@@ -4596,7 +4596,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Симулира ръчен скенер. Ръчните скенери често не знаят височината на "
 "образа а приори. Вместо това, те връщат стойност от -1. Пускането на "
@@ -4938,7 +4938,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Симулира ръчен скенер. Ръчните скенери не знаят височината на "
--- a/po/cs.po
+++ b/po/cs.po
@@ -4584,7 +4584,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Simuluje ruční skener. Ruční skenery obvykle neznají výšku obrázku "
 "předem. Proto vracejí výšku 1. Tato volba umožnuje otestovat, jestli se "
@@ -4925,7 +4925,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Simuluje ruční skener. Ruční skenery obvykle neznají výšku obrázku "
--- a/po/da.po
+++ b/po/da.po
@@ -4604,7 +4604,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Simulerer en håndskanner. Oftest kender en håndskanner ikke billedhøjden "
 "i forvejen. I stedet for returnerer de en højde på -1. Sættes denne "
@@ -4944,7 +4944,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Simulerer en håndskanner. Håndskannere kender ikke forud billedhøjden. I "
--- a/po/de.po
+++ b/po/de.po
@@ -4758,7 +4758,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Simuliere einen Handscanner. Bei Handscannern steht meistens die "
 "Bildhöhe nicht von vornherein fest. Stattdessen geben sie eine Höhe von "
@@ -5148,7 +5148,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Simuliere einen Handscanner. Bei Handscannern steht meistens die "
--- a/po/en_GB.po
+++ b/po/en_GB.po
@@ -4611,11 +4611,11 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 
 #: ../backend/pnm.c:283
 #, no-c-format
@@ -4952,12 +4952,12 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 
 #: ../backend/test.c:366
--- a/po/eo.po
+++ b/po/eo.po
@@ -4635,7 +4635,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Ĝi simulas akiradon per mana skanilo. La manaj skaniloj ofte ne rekonas "
 "la alton de la bildon apriore, do ili revenigas alton kun valoro -1. Per "
@@ -4977,7 +4977,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Ĝi simulas akiradon per mana skanilo. La manaj skaniloj ofte ne rekonas "
--- a/po/es.po
+++ b/po/es.po
@@ -4666,7 +4666,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Simula un escáner de mano. Los escáneres de mano a menudo no conocen a "
 "priori la distancia a la imagen. En su lugar utiliza una altura de "
@@ -5011,7 +5011,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Simula un escáner de mano. Los escáneres de mano a menudo no conocen a "
--- a/po/fi.po
+++ b/po/fi.po
@@ -4586,7 +4586,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Simuloi käsiskanneria. Käsiskannerit eivät yleensä tiedä kuvan kokoa "
 "etukäteen. Sen sijaan, ne palauttavat kuvan korkeudeksi -1. Tällä "
@@ -4926,7 +4926,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Simuloi käsikuvnalukijaa. Käsikuvanlukijat eivät tiedä kuvan korkeutta "
--- a/po/fr.po
+++ b/po/fr.po
@@ -4713,7 +4713,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Simule une numérisation avec un scanner à main. Les scanners à main ne "
 "connaissent pas à priori la hauteur de l'image. A la place, ils "
@@ -5057,7 +5057,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Simule un scanner à main. Les scanners à main ne connaissent pas à "
--- a/po/gl.po
+++ b/po/gl.po
@@ -4668,7 +4668,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Semella un escáner de man. Os escáneres de man adoitan descoñecer a "
 "priori a distancia á imaxe. Na súa vez utiliza unha altura de retorno "
@@ -5012,7 +5012,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Semella un escáner de man. Os escáneres de man adoitan descoñecer a "
--- a/po/it.po
+++ b/po/it.po
@@ -4661,7 +4661,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Simula l'acquisizione mediante uno scanner manuale; questi scanner "
 "spesso non conoscono l'altezza dell'immagine a priori e restituiscono "
@@ -5007,7 +5007,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Simulazione di acquisizione mediante uno scanner manuale; questi scanner "
--- a/po/ja.po
+++ b/po/ja.po
@@ -4567,7 +4567,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "ハンドスキャナーをシミュレートします。ハンドスキャナーは、たいていの場"
 "合、イメージの高さが事前にはわかりません。その代わり、高さとしてー1を返"
@@ -4891,7 +4891,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 
--- a/po/nb.po
+++ b/po/nb.po
@@ -4534,7 +4534,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 
 #: ../backend/pnm.c:283
@@ -4846,7 +4846,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 
--- a/po/nl.po
+++ b/po/nl.po
@@ -4745,7 +4745,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Simuleer een handscanner. Bij handscanners staat meestal de beeldhoogte "
 "van te voren niet vast. In plaats daarvan geven zij een hoogte van -1 "
@@ -5132,7 +5132,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Simuleer een handscanner. Bij handscanners staat tenminste de "
--- a/po/pl.po
+++ b/po/pl.po
@@ -4652,7 +4652,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Symuluje skaner ręczny. Skanery ręczne zwykle nie znają wysokości "
 "obrazka. Zamiast tego zwracają wysokość -1. Ustawienie tej opcji pozwala "
@@ -4994,7 +4994,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Symuluje skaner ręczny. Skanery ręczne zwykle nie znają wysokości "
--- a/po/pt.po
+++ b/po/pt.po
@@ -3979,7 +3979,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 
 #: ../backend/pnm.c:283
@@ -4291,7 +4291,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 
--- a/po/ru.po
+++ b/po/ru.po
@@ -4661,7 +4661,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Имитирует ручной сканер. Ручные сканеры часто не имеют информации о "
 "длине изображения. Вместо этого они возвращает длину -1. Установка этого "
@@ -4992,7 +4992,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Имитировать ручной сканер. Ручные сканеры никогда не знают о высоте "
--- a/po/sv.po
+++ b/po/sv.po
@@ -4701,7 +4701,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Simulera en handbildläsare. Handbildläsare vet oftast inte bildhöjden i "
 "förväg. I stället returnerar de en höjd som är -1. Om denna inställning "
@@ -5043,7 +5043,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Simulera en handbildläsare. Handbildläsare vet oftast inte bildhöjden i "
--- a/po/uk.po
+++ b/po/uk.po
@@ -4775,7 +4775,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners often do not know the image "
 "height a priori.  Instead, they return a height of -1.  Setting this "
-"option allows to test whether a frontend can handle this correctly."
+"option allows one to test whether a frontend can handle this correctly."
 msgstr ""
 "Імітує ручний сканер. Ручні сканери часто попередньо не отримують даних "
 "щодо висоти зображення. Замість цього, вони повертають висоту рівну -1. "
@@ -5164,7 +5164,7 @@
 msgid ""
 "Simulate a hand-scanner.  Hand-scanners do not know the image height a "
 "priori.  Instead, they return a height of -1.  Setting this option "
-"allows to test whether a frontend can handle this correctly.  This "
+"allows one to test whether a frontend can handle this correctly.  This "
 "option also enables a fixed width of 11 cm."
 msgstr ""
 "Імітує ручний сканер. Ручні сканери попередньо не отримують даних щодо "
--- a/backend/test.c
+++ b/backend/test.c
@@ -348,7 +348,7 @@
   od->title = SANE_I18N ("Hand-scanner simulation");
   od->desc = SANE_I18N ("Simulate a hand-scanner.  Hand-scanners do not "
 			"know the image height a priori.  Instead, they "
-			"return a height of -1.  Setting this option allows "
+			"return a height of -1.  Setting this option allows one "
 			"to test whether a frontend can handle this "
 			"correctly.  This option also enables a fixed width "
 			"of 11 cm.");
--- a/backend/pixma_bjnp.c
+++ b/backend/pixma_bjnp.c
@@ -553,7 +553,7 @@
 set_cmd (int devno, struct BJNP_command *cmd, char cmd_code, int payload_len)
 {
   /*
    * Set command buffer with command code, session_id and lenght of payload
    * Returns: sequence number of command
    */
   strncpy (cmd->BJNP_id, BJNP_STRING, sizeof (cmd->BJNP_id));
@@ -732,7 +732,7 @@
   id->id[id_len] = '\0';
   strcpy (scanner_id, id->id);
 
-  PDBG (bjnp_dbg (LOG_INFO, "Scanner identity string = %s - lenght = %d\n", scanner_id, id_len));
+  PDBG (bjnp_dbg (LOG_INFO, "Scanner identity string = %s - length = %d\n", scanner_id, id_len));
 
   /* get make&model from IEEE1284 id  */
 
@@ -553,7 +553,7 @@
 {
   /*
-   * Set command buffer with command code, session_id and lenght of payload
+   * Set command buffer with command code, session_id and length of payload
    * Returns: sequence number of command
    */